import React, { PropTypes } from 'react'
// import styled, { css } from 'styled-components'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import theme from './theme'

const nakedStyle = () => css({
  backgroundColor: 'transparent',
  '&:hover': {
    backgroundColor: theme.colors.tint[1]
  },
  '&:active': {
    backgroundColor: theme.colors.tint[2]
  }
})

const intentStateStyle = intentState => ({
  backgroundColor: intentState.backgroundColor,
  color: intentState.textColor,
  ...(intentState.boxShadow ? {
    boxShadow: intentState.boxShadow
  } : {})
})

const intentStyle = intent => ({
  ...intentStateStyle(intent.default),
  '&:hover': {
    ...intentStateStyle(intent.hover)
  },
  '&:focus': {
    ...intentStateStyle(intent.focus)
  },
  '&:active': {
    ...intentStateStyle(intent.active)
  }
})

const getStyle = ({ primary, secondary, danger, naked }) => {
  if (primary) return css(intentStyle(theme.intent['primary']))
  if (danger) return css(intentStyle(theme.intent['danger']))
  if (naked) return css(nakedStyle())
  if (secondary) return css(intentStyle(theme.intent['secondary'])) /* default */
  return ''
}

const baseStyles = css({
  textTransform: 'capitalize',
  border: 0,
  fontWeight: 400,
  textDecoration: 'none',
  transition: theme.animationDuration.faster,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  cursor: 'pointer',
  whiteSpace: 'nowrap',
  userSelect: 'none',
  '&:active, &:focus': {
    outline: 'none'
  }
})

const styles = ({
  primary,
  secondary,
  danger,
  naked,
  theme
}) => css`
  text-transform: capitalize;
  border: 0;
  display: inline-block;
  font-weight: 400;
  text-decoration: none;
  transition: 120ms;
  transition-property: background-color, color, box-shadow, opacity;
  cursor: pointer;
  text-align: center;
  white-space: nowrap;
  user-select: none;

  ${getStyle({ primary, secondary, danger, naked }, theme)}

  &:active,
  &:focus {
    outline: none;
  }
`

const parseProps = ({
  className,
  primary,
  secondary,
  danger,
  naked,
  ...props
}) => ({
  className: cx(`${baseStyles}`, `${getStyle({ primary, secondary, danger, naked })}`, className),
  ...props
})

const Button = props => <Box {...parseProps(props)} />

Button.propTypes = {
  ...Box.propTypes,
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  naked: PropTypes.bool
}

Button.defaultProps = {
  is: 'button',
  display: 'inline-block',
  textAlign: 'center',
  secondary: true,
  rounded: true,
  paddingX: 4,
  paddingY: 2,
  textStyle: 'body1'
}

Button.displayName = 'Button'

export default Button
