import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import theme from './../components/theme'

export const propTypes = {
  textStyle: PropTypes.oneOf(Object.keys(theme.textStyles)),
  bold: PropTypes.bool
}

const getTextStyle = ({ fontSize, fontWeight, lineHeight, letterSpacing }, textStyle) => ({
  fontSize,
  fontWeight,
  lineHeight,
  letterSpacing,
  ...(textStyle.indexOf('caps') > -1 ? { textTransform: 'uppercase' } : {}),
  ...(textStyle.indexOf('mono') > -1 ? { fontFamily: theme.fonts.mono } : {})
})

const getClassName = ({
  textStyle,
  bold
}) => css({
  ...(textStyle ? getTextStyle(theme.textStyles[textStyle], textStyle) : {}),
  ...(bold ? { fontWeight: '500' } : {})
})

export const parseProps = ({
  textStyle,
  bold,
  className,
  ...props
}) => {
  if (textStyle !== undefined || bold !== undefined) {
    return {
      className: cx(className, `${getClassName({ textStyle, bold })}`),
      ...props
    }
  }
  return { className, ...props }
}
